# When downloading directly from Mercurial, it will automatically add this prefix
# Invoking 'hg archive' wont but you can add one with:
# hg archive -t tgz -p "Linux-HA-Dev-" -r $upstreamversion $upstreamversion.tar.gz
%define upstreamprefix Heartbeat-3-0-
%define upstreamversion STABLE-3.0.5

%define gname haclient
%define uname hacluster

Summary: Messaging and membership subsystem for High-Availability Linux
Name: heartbeat
Version: 3.0.5
Release: %mkrel 1
License: GPLv2 and LGPLv2+
URL: http://linux-ha.org/
Group: System/Servers
Source0: http://hg.linux-ha.org/heartbeat-STABLE_3_0/archive/STABLE-%{version}.tar.bz2
Patch1: heartbeat-3.0.4-disable-xinclude.patch
Patch2: heartbeat-3.0.0-haresources.patch
Patch3: heartbeat-3.0.4-link.patch
Patch4: heartbeat-3.0.4-lsbinit.patch
BuildRequires: glib2-devel
BuildRequires: iputils
BuildRequires: libltdl-devel
BuildRequires: net-snmp-devel >= 5.4
BuildRequires: bzip2-devel
BuildRequires: ncurses-devel
BuildRequires: openssl-devel
BuildRequires: libxml2-devel
BuildRequires: gettext
BuildRequires: bison
BuildRequires: flex
BuildRequires: zlib-devel
BuildRequires: mailx
BuildRequires: which
BuildRequires: cluster-glue-devel
BuildRequires: libuuid-devel
BuildRequires: xsltproc
BuildRequires: docbook-style-xsl
Requires: python-pyxml
Requires: resource-agents

%description
heartbeat is a basic high-availability subsystem for Linux-HA.
It will run scripts at initialization, and when machines go up or down.
This version will also perform IP address takeover using gratuitous ARPs.

Heartbeat contains a cluster membership layer, fencing, and local and
clusterwide resource management functionality.

When used with Pacemaker, it supports "n-node" clusters with significant 
capabilities for managing resources and dependencies.

In addition it continues to support the older release 1 style of
2-node clustering.

It implements the following kinds of heartbeats:
 - Serial ports
 - UDP/IP multicast (ethernet, etc)
 - UDP/IP broadcast (ethernet, etc)
 - UDP/IP heartbeats
 - "ping" heartbeats (for routers, switches, etc.)
 (to be used for breaking ties in 2-node systems)

%files
%doc %{_datadir}/doc/%{name}-%{version}
%dir %{_sysconfdir}/ha.d
%{_sysconfdir}/ha.d/harc
%{_sysconfdir}/ha.d/rc.d
%config(noreplace) %{_sysconfdir}/ha.d/README.config
%{_datadir}/heartbeat/
%{_sysconfdir}/ha.d/resource.d/
%{_sysconfdir}/init.d/heartbeat
%config(noreplace) %{_sysconfdir}/logrotate.d/heartbeat
%dir %{_var}/lib/heartbeat
%dir %{_var}/run/heartbeat
%attr (2755, %{uname}, %{gname}) %{_bindir}/cl_status
%{_bindir}/cl_respawn
%dir %attr (755, %{uname}, %{gname}) %{_var}/run/heartbeat/ccm
%{_mandir}/man1/cl_status.1*
%{_mandir}/man1/hb_standby.1*
%{_mandir}/man1/hb_takeover.1*
%{_mandir}/man1/hb_addnode.1*
%{_mandir}/man1/hb_delnode.1*
%{_mandir}/man8/heartbeat.8*
%{_mandir}/man8/apphbd.8*
%{_mandir}/man5/authkeys.5*
%{_mandir}/man5/ha.cf.5*
%{_libdir}/heartbeat

#---------------------------------------------------------
%define apphbmajor 2
%define libapphb %mklibname apphb %apphbmajor

%package -n %libapphb
Summary:	Heartbeat libraries
Group:		System/Libraries
Requires:	%{name} = %{version}-%{release}

%description -n %libapphb
Heartbeat library package.

%files -n %libapphb
%{_libdir}/libapphb.so.%{apphbmajor}
%{_libdir}/libapphb.so.%{apphbmajor}.*

#---------------------------------------------------------
%define ccmclientmajor 1
%define libccmclient %mklibname ccmclient %ccmclientmajor

%package -n %libccmclient
Summary:	Heartbeat libraries
Group:		System/Libraries
Requires:	%{name} = %{version}-%{release}
Obsoletes:	%{_lib}heartbeat1 < 3.0.0

%description -n %libccmclient
Heartbeat library package.

%files -n %libccmclient
%{_libdir}/libccmclient.so.%{ccmclientmajor}
%{_libdir}/libccmclient.so.%{ccmclientmajor}.*

#---------------------------------------------------------
%define clmmajor 1
%define libclm %mklibname clm %clmmajor

%package -n %libclm
Summary:	Heartbeat libraries
Group:		System/Libraries
Requires:	%{name} = %{version}-%{release}
Obsoletes:	%{_lib}heartbeat1 < 3.0.0

%description -n %libclm
Heartbeat library package.

%files -n %libclm
%{_libdir}/libclm.so.%{clmmajor}
%{_libdir}/libclm.so.%{clmmajor}.*

#---------------------------------------------------------
%define hbclientmajor 1
%define libhbclient %mklibname hbclient %hbclientmajor

%package -n %libhbclient
Summary:	Heartbeat libraries
Group:		System/Libraries
Requires:	%{name} = %{version}-%{release}
Obsoletes:	%{_lib}heartbeat1 < 3.0.0

%description -n %libhbclient
Heartbeat library package.

%files -n %libhbclient
%{_libdir}/libhbclient.so.%{hbclientmajor}
%{_libdir}/libhbclient.so.%{hbclientmajor}.*

#---------------------------------------------------------
%package devel
Summary: Heartbeat development package
Group: Development/Other
Requires: %libapphb = %{version}-%{release}
Requires: %libccmclient = %{version}-%{release}
Requires: %libclm = %{version}-%{release}
Requires: %libhbclient = %{version}-%{release}
Obsoletes: %{_lib}heartbeat1-devel < 3.0.0

%description devel
Headers and shared libraries for writing programs for Heartbeat.

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/*.la

#---------------------------------------------------------
%prep
%setup -q -n %{upstreamprefix}%{upstreamversion}
%patch1 -p1
%patch2 -p1 
%patch3 -p0 -b .link
%patch4 -p0

%build
./bootstrap
%configure2_5x --disable-fatal-warnings --disable-static

# get rid of rpath
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}
# disable xsltproc from trying to hit the net
export XSLTPROC_OPTIONS=""
%makeinstall_std

# cleanup
[ -d %{buildroot}/usr/man ] && rm -rf %{buildroot}/usr/man
[ -d %{buildroot}/usr/share/libtool ] && rm -rf %{buildroot}/usr/share/libtool
mv %{buildroot}/%{_datadir}/doc/%{name} %{buildroot}/%{_datadir}/doc/%{name}-%{version}
rm -rf %{buildroot}/%{_datadir}/heartbeat/cts

%clean
rm -rf %{buildroot}

%post
%_post_service heartbeat

%preun
%_preun_service heartbeat



%changelog
* Thu Nov 03 2011 Andrey Bondrov <abondrov@mandriva.org> 3.0.5-1mdv2012.0
+ Revision: 716220
- New version 3.0.5 (move from 2.x to 3.x), major spec update based on Funda Wang's work in Mageia

* Mon Jul 18 2011 Oden Eriksson <oeriksson@mandriva.com> 2.1.4-5
+ Revision: 690292
- rebuilt against new net-snmp libs

* Fri Jun 17 2011 Luis Daniel Lucio Quiroz <dlucio@mandriva.org> 2.1.4-4
+ Revision: 685747
- Add some suggestions for ldirectord to make life happier

* Wed Jun 08 2011 Luis Daniel Lucio Quiroz <dlucio@mandriva.org> 2.1.4-3
+ Revision: 683148
- Fix a require for stnoith

* Sun May 08 2011 Funda Wang <fwang@mandriva.org> 2.1.4-2
+ Revision: 672404
- fix multiarch usage

  + Oden Eriksson <oeriksson@mandriva.com>
    - mass rebuild

* Tue Oct 12 2010 Funda Wang <fwang@mandriva.org> 2.1.4-1mdv2011.0
+ Revision: 585013
- BR flex
- BR bison

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - "new" release: 2.1.4
    - be sure to create the required 'hacluster' account
    - drop ldconfig scriptlets for no longer supported releases
    - fix ownership of orphan directories

* Mon Jun 07 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.1.3-14mdv2010.1
+ Revision: 547216
- fix cl_status permissions (mdv# 58947)

* Sat May 01 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.1.3-13mdv2010.1
+ Revision: 541430
- add upstream patch to fix basic fall over

* Wed Apr 07 2010 Funda Wang <fwang@mandriva.org> 2.1.3-12mdv2010.1
+ Revision: 532624
- fix linkage with newer ldflag

* Fri Feb 26 2010 Oden Eriksson <oeriksson@mandriva.com> 2.1.3-11mdv2010.1
+ Revision: 511573
- rebuilt against openssl-0.9.8m

* Mon Nov 30 2009 Oden Eriksson <oeriksson@mandriva.com> 2.1.3-10mdv2010.1
+ Revision: 471948
- fix #45032, #48438

* Mon Nov 30 2009 Oden Eriksson <oeriksson@mandriva.com> 2.1.3-9mdv2010.1
+ Revision: 471763
- P3: security fix for CVE-2009-3736

* Wed Nov 18 2009 Oden Eriksson <oeriksson@mandriva.com> 2.1.3-8mdv2010.1
+ Revision: 467258
- fix %%install stage
- link against system libltdl.so.7

* Thu Oct 15 2009 Oden Eriksson <oeriksson@mandriva.com> 2.1.3-7mdv2010.0
+ Revision: 457612
- rebuilt against new net-snmp libs

* Thu Oct 08 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 2.1.3-6mdv2010.0
+ Revision: 455865
- rebuild for new curl SSL backend

* Mon Oct 05 2009 Guillaume Rousse <guillomovitch@mandriva.org> 2.1.3-5mdv2010.0
+ Revision: 454234
- small %%files cleanup
- no need to requires a specific syslog implementation

* Wed Sep 30 2009 Michael Scherer <misc@mandriva.org> 2.1.3-4mdv2010.0
+ Revision: 451453
- fix heartbeat installation, as reported by scred on irc

* Thu Jun 04 2009 Oden Eriksson <oeriksson@mandriva.com> 2.1.3-3mdv2010.0
+ Revision: 382699
- rebuilt against libnet 1.1.3

* Thu Apr 09 2009 Funda Wang <fwang@mandriva.org> 2.1.3-2mdv2009.1
+ Revision: 365335
- rediff init patch

  + Antoine Ginies <aginies@mandriva.com>
    - rebuild

* Wed Jul 02 2008 Oden Eriksson <oeriksson@mandriva.com> 2.1.3-1mdv2009.0
+ Revision: 230801
- 2.1.3
- disable -Wl,--as-needed -Wl,--no-undefined, it's too complicated
  and almost no gain spending time fixing it.

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

* Mon Jan 21 2008 Funda Wang <fwang@mandriva.org> 2.0.8-5mdv2008.1
+ Revision: 155595
- BR db-devel
- rebuild

  + Olivier Blin <blino@mandriva.org>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Aug 08 2007 Oden Eriksson <oeriksson@mandriva.com> 2.0.8-4mdv2008.0
+ Revision: 60227
- bump release
- fix build
- rebuilt against new net-snmp libs

* Thu Jun 28 2007 Andreas Hasenack <andreas@mandriva.com> 2.0.8-2mdv2008.0
+ Revision: 45539
- rebuild with new serverbuild macro in proper place
- fix docdir

* Mon May 28 2007 Andreas Hasenack <andreas@mandriva.com> 2.0.8-1mdv2008.0
+ Revision: 32135
- updated to version 2.0.8


* Tue Apr 03 2007 Nicolas Lécureuil <neoclust@mandriva.org> 2.0.7-11mdv2007.1
+ Revision: 150261
- Fix error in summary (Kournikola)

* Thu Mar 15 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.0.7-10mdv2007.1
+ Revision: 144274
- drop explicit dependency on libapphb.so.0 making devel package uninstallable on x86_64

* Fri Jan 05 2007 Andreas Hasenack <andreas@mandriva.com> 2.0.7-9mdv2007.1
+ Revision: 104424
- rebuild with new curl
- bump release, previous packages is still in upload queue
- added buildrequires for pam-devel
- bumped release, previous upload attempt was still in the queue
- added buildrequires for python-devel
- added buildrequires for ncurses-devel
- rebuild with new ncurses

* Sat Aug 26 2006 Andreas Hasenack <andreas@mandriva.com> 2.0.7-5mdv2007.0
+ Revision: 58152
- add provides for heartbeat initscript

* Fri Aug 25 2006 Thierry Vignaud <tvignaud@mandriva.com> 2.0.7-4mdv2007.0
+ Revision: 57829
- fix build on x86_64

* Thu Aug 17 2006 Andreas Hasenack <andreas@mandriva.com> 2.0.7-3mdv2007.0
+ Revision: 56450
- bumped release
- fixed file conflicts

* Wed Aug 16 2006 Andreas Hasenack <andreas@mandriva.com> 2.0.7-2mdv2007.0
+ Revision: 56246
- bump release
- cleanup
- exclude devel plugin files from parent package

* Tue Aug 15 2006 Andreas Hasenack <andreas@mandriva.com> 2.0.7-1mdv2007.0
+ Revision: 55974
- formatting
- updated to version 2.0.7, fixing a security vulnerability

* Fri Aug 04 2006 Andreas Hasenack <andreas@mandriva.com> 2.0.6-1mdv2007.0
+ Revision: 48063
- revert previous fix and use an improved one
- fix x86_64 build (patch by Oden)
- split libapphb, it didn't change soname from heartbeat-1
- update major, added necessary conflicts
- updated to version 2.0.6, work done by Cris B <cris@beebgames.com>
- reapplied ldirectord usage patch
- added libgnutls-devel to buildrequires
- added signed checksum file
- added svn warning
- import heartbeat-1.2.4-2mdv2007.0

* Tue Jun 13 2006 Andreas Hasenack <andreas@mandriva.com> 1.2.4-2mlcs4
- make the main package require heartbeat-pils or else the daemon won't
  even start (#23050)

* Wed Jun 07 2006 Per yvind Karlsen <pkarlsen@mandriva.com> 1.2.4-1mdv2007.0
- New release 1.2.4
- fix executable-marked-as-config-file for init scripts
- disable fail on warnings
- regenerate P3
- drop P4 & P5 (fixed upstream)

* Fri Mar 17 2006 Oden Eriksson <oeriksson@mandriva.com> 1.2.3-9mdk
- rebuilt against libnet1.1.2

* Wed Jan 04 2006 Oden Eriksson <oeriksson@mandriva.com> 1.2.3-8mdk
- rebuilt against new net-snmp with new major (10)

* Wed Dec 21 2005 Oden Eriksson <oeriksson@mandriva.com> 1.2.3-7mdk
- rebuilt against net-snmp that has new major (9)

* Mon Nov 14 2005 Oden Eriksson <oeriksson@mandriva.com> 1.2.3-6mdk
- rebuilt against openssl-0.9.8a

* Sun Aug 14 2005 Olivier Blin <oblin@mandriva.com> 1.2.3-5mdk
- multiarch support

* Sat Aug 13 2005 Olivier Blin <oblin@mandriva.com> 1.2.3-4mdk
- fix wrong operator in BuildRequires (thanks to Gwenole)
- remove Requires on release
- fix prereq

* Sat Aug 13 2005 Olivier Blin <oblin@mandriva.com> 1.2.3-3mdk
- from Vincent Danen: security update for CAN-2005-2231
- fix BuildRequires
- Patch5: gcc4 fixes

* Wed Dec 15 2004 Buchan  Milne <bgmilne@linux-mandrake.com> 1.2.3-2mdk
- fix build on 10.0 and older
- ditro-specific release tag

* Fri Nov 12 2004 Per yvind Karlsen <peroyvind@linux-mandrake.com> 1.2.3-1mdk
- 1.2.3

* Mon Aug 02 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 1.2.2-2mdk
- fix deps
- misc spec file fixes

* Tue Jun 01 2004 Per yvind Karlsen <peroyvind@linux-mandrake.com> 1.2.2-1mdk
- 1.2.2
- use libtoolize again
- cosmetics

* Sat May 08 2004 Erwan Velu <erwan@mandrakesoft.com> 1.2.1-1mdk
- 1.2.1
- Adding missing files

